==> mediawiki-1.25.3-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/languages/messages/MessagesAvk.php <==
<?php
/** Kotava (Kotava)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$namespaceNames = array(
	NS_MEDIA            => 'Mamind',
	NS_SPECIAL          => 'Aptaca',
	NS_TALK             => 'Prilara',
	NS_USER             => 'Favesik',
	NS_USER_TALK        => 'Favesikprilara',
	NS_PROJECT_TALK     => '$1 prilara',
	NS_FILE             => 'Ewava',
	NS_FILE_TALK        => 'Ewavaprilara',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki prilara',
	NS_TEMPLATE         => 'Teza',
	NS_TEMPLATE_TALK    => 'Tezaprilara',
	NS_HELP             => 'Pomara',
	NS_HELP_TALK        => 'Pomaraprilara',
	NS_CATEGORY         => 'Loma',
	NS_CATEGORY_TALK    => 'Lomaprilara',
);

$specialPageAliases = array(
	'Allmessages'               => array( 'Stakseem' ),
	'Allpages'                  => array( 'Bueem' ),
	'Ancientpages'              => array( 'SavsafBueem' ),
	'Booksources'               => array( 'NevaKliteem' ),
	'BrokenRedirects'           => array( 'EmpayanGraskakseem' ),
	'Categories'                => array( 'Lomeem' ),
	'Confirmemail'              => array( 'EmailManeGruyera' ),
	'Contributions'             => array( 'Webekseem' ),
	'Deadendpages'              => array( 'AxodafBueem' ),
	'DoubleRedirects'           => array( 'JontolafGraskakseem' ),
	'Emailuser'                 => array( 'FavesikEmailMane' ),
	'Export'                    => array( 'Divburera' ),
	'Fewestrevisions'           => array( 'Lebetayan' ),
	'Import'                    => array( 'Koburera' ),
	'Listadmins'                => array( 'Ristusikeem' ),
	'Listbots'                  => array( 'Stiernikeem' ),
	'Listfiles'                 => array( 'Ewaveem' ),
	'Listredirects'             => array( 'Graskakseem' ),
	'Listusers'                 => array( 'Favesikeem' ),
	'Lonelypages'               => array( 'GluyasikiiskafBueem' ),
	'Longpages'                 => array( 'AbrotcafBueem' ),
	'MIMEsearch'                => array( 'MIMEAneyara' ),
	'Mostcategories'            => array( 'Lolomakiraf' ),
	'Mostimages'                => array( 'Lodewavakiraf' ),
	'Mostlinked'                => array( 'Logluyasikikiraf' ),
	'Mostlinkedcategories'      => array( 'LogluyasikirafLomeem' ),
	'Mostlinkedtemplates'       => array( 'LogluyasikikirafTezeem' ),
	'Mostrevisions'             => array( 'Lobetayan' ),
	'Movepage'                  => array( 'BuArrundara' ),
	'Mycontributions'           => array( 'JinafWebekseem' ),
	'Mypage'                    => array( 'JinafuBu' ),
	'Mytalk'                    => array( 'JinafaPrilara' ),
	'Newimages'                 => array( 'WarzafEwaveem' ),
	'Newpages'                  => array( 'WarzafBueem' ),

	'Preferences'               => array( 'Lodamaceem' ),
	'Protectedpages'            => array( 'NendanBueem' ),
	'Protectedtitles'           => array( 'NendanVergumvelteem' ),
	'Randompage'                => array( 'Xuyavabu' ),
	'Randomredirect'            => array( 'XuyavafaGraskara' ),
	'Recentchanges'             => array( 'NoeltafBetakseem' ),
	'Revisiondelete'            => array( 'BetaraSulara' ),
	'Search'                    => array( 'Aneyara' ),
	'Shortpages'                => array( 'TrelafBueem' ),
	'Specialpages'              => array( 'AptafBueem' ),
	'Statistics'                => array( 'Enkopaceem' ),
	'Uncategorizedcategories'   => array( 'LomiskafLomeem' ),
	'Uncategorizedimages'       => array( 'LomiskafEwaveem' ),
	'Uncategorizedpages'        => array( 'LomiskafBueem' ),
	'Uncategorizedtemplates'    => array( 'LomiskafTezeem' ),
	'Undelete'                  => array( 'Dimsulara' ),
	'Unusedcategories'          => array( 'MefavenLomeem' ),
	'Unusedimages'              => array( 'MefavenEwaveem' ),
	'Unusedtemplates'           => array( 'MefavenTezeem' ),
	'Unwatchedpages'            => array( 'MerupenBueem' ),
	'Upload'                    => array( 'Kalvajara' ),
	'Userrights'                => array( 'FavesikRokeem' ),
	'Version'                   => array( 'Siatos' ),
	'Wantedcategories'          => array( 'ErunLomeem' ),
	'Wantedpages'               => array( 'ErunBueem', 'EmpayanGluyasikieem' ),
	'Watchlist'                 => array( 'Suzdasiki' ),
);

==> mediawiki-1.26.2-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/languages/messages/MessagesAvk.php <==
<?php
/** Kotava (Kotava)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$namespaceNames = array(
	NS_MEDIA            => 'Mamind',
	NS_SPECIAL          => 'Aptaca',
	NS_TALK             => 'Prilara',
	NS_USER             => 'Favesik',
	NS_USER_TALK        => 'Favesikprilara',
	NS_PROJECT_TALK     => '$1_prilara',
	NS_FILE             => 'Ewava',
	NS_FILE_TALK        => 'Ewavaprilara',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki_prilara',
	NS_TEMPLATE         => 'Teza',
	NS_TEMPLATE_TALK    => 'Tezaprilara',
	NS_HELP             => 'Pomara',
	NS_HELP_TALK        => 'Pomaraprilara',
	NS_CATEGORY         => 'Loma',
	NS_CATEGORY_TALK    => 'Lomaprilara',
);

$specialPageAliases = array(
	'Allmessages'               => array( 'Stakseem' ),
	'Allpages'                  => array( 'Bueem' ),
	'Ancientpages'              => array( 'SavsafBueem' ),
	'Booksources'               => array( 'NevaKliteem' ),
	'BrokenRedirects'           => array( 'EmpayanGraskakseem' ),
	'Categories'                => array( 'Lomeem' ),
	'Confirmemail'              => array( 'EmailManeGruyera' ),
	'Contributions'             => array( 'Webekseem' ),
	'Deadendpages'              => array( 'AxodafBueem' ),
	'DoubleRedirects'           => array( 'JontolafGraskakseem' ),
	'Emailuser'                 => array( 'FavesikEmailMane' ),
	'Export'                    => array( 'Divburera' ),
	'Fewestrevisions'           => array( 'Lebetayan' ),
	'Import'                    => array( 'Koburera' ),
	'Listadmins'                => array( 'Ristusikeem' ),
	'Listbots'                  => array( 'Stiernikeem' ),
	'Listfiles'                 => array( 'Ewaveem' ),
	'Listredirects'             => array( 'Graskakseem' ),
	'Listusers'                 => array( 'Favesikeem' ),
	'Lonelypages'               => array( 'GluyasikiiskafBueem' ),
	'Longpages'                 => array( 'AbrotcafBueem' ),
	'MIMEsearch'                => array( 'MIMEAneyara' ),
	'Mostcategories'            => array( 'Lolomakiraf' ),
	'Mostimages'                => array( 'Lodewavakiraf' ),
	'Mostlinked'                => array( 'Logluyasikikiraf' ),
	'Mostlinkedcategories'      => array( 'LogluyasikirafLomeem' ),
	'Mostlinkedtemplates'       => array( 'LogluyasikikirafTezeem' ),
	'Mostrevisions'             => array( 'Lobetayan' ),
	'Movepage'                  => array( 'BuArrundara' ),
	'Mycontributions'           => array( 'JinafWebekseem' ),
	'Mypage'                    => array( 'JinafuBu' ),
	'Mytalk'                    => array( 'JinafaPrilara' ),
	'Newimages'                 => array( 'WarzafEwaveem' ),
	'Newpages'                  => array( 'WarzafBueem' ),
	'Preferences'               => array( 'Lodamaceem' ),
	'Protectedpages'            => array( 'NendanBueem' ),
	'Protectedtitles'           => array( 'NendanVergumvelteem' ),
	'Randompage'                => array( 'Xuyavabu' ),
	'Randomredirect'            => array( 'XuyavafaGraskara' ),
	'Recentchanges'             => array( 'NoeltafBetakseem' ),
	'Revisiondelete'            => array( 'BetaraSulara' ),
	'Search'                    => array( 'Aneyara' ),
	'Shortpages'                => array( 'TrelafBueem' ),
	'Specialpages'              => array( 'AptafBueem' ),
	'Statistics'                => array( 'Enkopaceem' ),
	'Uncategorizedcategories'   => array( 'LomiskafLomeem' ),
	'Uncategorizedimages'       => array( 'LomiskafEwaveem' ),
	'Uncategorizedpages'        => array( 'LomiskafBueem' ),
	'Uncategorizedtemplates'    => array( 'LomiskafTezeem' ),
	'Undelete'                  => array( 'Dimsulara' ),
	'Unusedcategories'          => array( 'MefavenLomeem' ),
	'Unusedimages'              => array( 'MefavenEwaveem' ),
	'Unusedtemplates'           => array( 'MefavenTezeem' ),
	'Unwatchedpages'            => array( 'MerupenBueem' ),
	'Upload'                    => array( 'Kalvajara' ),
	'Userrights'                => array( 'FavesikRokeem' ),
	'Version'                   => array( 'Siatos' ),
	'Wantedcategories'          => array( 'ErunLomeem' ),
	'Wantedpages'               => array( 'ErunBueem', 'EmpayanGluyasikieem' ),
	'Watchlist'                 => array( 'Suzdasiki' ),
);
